pub struct ProgressEvent {
pub frame: u64,
pub fps: f64,
pub bitrate: Box<str>,
pub progress: Box<str>,
pub total_size: Option<u64>,
pub out_time_us: i64,
pub out_time_ms: i64,
pub out_time: Box<str>,
pub dup_frames: u64,
pub drop_frames: u64,
pub speed: Option<f64>,
pub extra: HashMap<Box<str>, Box<str>>,
}Expand description
An event about the encoding progress sent by ffmpeg
Fields
frame: u64The frame number
fps: f64The fps
bitrate: Box<str>The bitrate
progress: Box<str>The progress
total_size: Option<u64>The total size.
None means either it was not present, or it was N/A
out_time_us: i64The out time in us
out_time_ms: i64The out time in ms
out_time: Box<str>The out time
dup_frames: u64The # of dup frames
drop_frames: u64The # of dropped frames
speed: Option<f64>The speed.
None means it was N/A.
extra: HashMap<Box<str>, Box<str>>Extra K/Vs